@@ -11,10 +11,10 @@ class Poster:
         self.title = None
         self.tracks = {}
         self.type_list = []
+        self.loader_list = []
         self.length_range_by_date = ValueRange()
         self.length_range_by_date_dict = defaultdict(ValueRange)
         self.units = "metric"
-        self.font = "Arial"
         self.colors = {
             "background": "#222222",
             "text": "#FFFFFF",
@@ -32,6 +32,9 @@ class Poster:
         self.year_tracks_date_count_dict = defaultdict(int)
         self.year_tracks_type_dict = defaultdict(dict)
 
+        # for year sumary
+        self.is_summary = False
+
     def set_tracks(self, tracks, years, type_list):
         self.type_list.extend(type_list)
         self.tracks = tracks
@@ -46,7 +49,7 @@ class Poster:
             else:
                 self.length_range_by_date.extend(num)
         for t in type_list:
-            self.__compute_track_statistics(t)
+            self.compute_track_statistics(t)
 
     @property
     def is_multiple_type(self):
@@ -88,17 +91,17 @@ class Poster:
         d.save()
 
     def __draw_tracks(self, d, offset):
-        self.tracks_drawer.draw(d, offset)
+        self.tracks_drawer.draw(d, offset, self.is_summary)
 
     def __draw_header(self, d):
         text_color = self.colors["text"]
-        title_style = f"font-size:12px; font-family:{self.font}; font-weight:bold;"
+        title_style = "font-size:12px; font-family:Arial; font-weight:bold;"
         d.add(d.text(self.title, insert=(10, 20), fill=text_color, style=title_style))
 
     def __draw_footer(self, d):
         self.tracks_drawer.draw_footer(d)
 
-    def __compute_track_statistics(self, t):
+    def compute_track_statistics(self, t):
         total_sum_year_dict = defaultdict(int)
         for date, num in self.tracks.items():
             if type(num) is dict:
